/*******************************************************************************
 * Copyright (c) 2009 Ferenc Hechler - ferenc_hechler@users.sourceforge.net
 * 
 * This file is part of the Android Hotspot Login
 *
 * The Android Hotspot Login is free software;
 * you can redistribute it and/or modify it under the terms of the GNU
 * General Public License as published by the Free Software Foundation;
 * either version 2 of the License, or (at your option) any later version.
 * 
 * The Android Hotspot Login is distributed
 * in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with the Android Hotspot Login;
 * if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  
 *******************************************************************************/
package net.sf.andhsli.hotspotlogin;

import java.util.HashMap;
import java.util.Map;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;


public class Params {

	private static final String TAG = "HSLI.params";
	private Map<String,SsidParams> allParams;
	private SsidParams currentSsidParams;

	public Params() {
		init();
	}
	
	private void init() {
		allParams = new HashMap<String,SsidParams>(3);
		SsidParams sp = new SsidParams();
		sp.setSSID("tmobile");
		allParams.put(sp.getSSID(),sp);
		sp = new SsidParams();
		sp.setSSID("Telekom");
		allParams.put(sp.getSSID(),sp);
		sp = new SsidParams();
		sp.setSSID("Telekom_ICE");
		allParams.put(sp.getSSID(),sp);
		sp = new SsidParams();
		sp.setSSID("WLAN_am_Bahnhof");
		allParams.put(sp.getSSID(),sp);
		sp = new SsidParams();
		sp.setSSID("T-Mobile_ICE");
		allParams.put(sp.getSSID(),sp);
		sp = new SsidParams();
		sp.setSSID("T-Mobile_T-Com");
		allParams.put(sp.getSSID(),sp);
		try {
			Log.i(TAG, toJSON(0));
			Log.i(TAG, toJSON(1));
		} catch (JSONException e) {
			Log.e(TAG,e.getMessage(),e);
		}
		setCurrentSsid(null);
	}
	
	/**
	 * {ssidparams1}
	 * @param indent
	 * @return
	 * @throws JSONException
	 */
	public String toJSON(int indent) throws JSONException {
		JSONArray ja = new JSONArray();
		for (SsidParams sp:allParams.values()) {
			JSONObject jo = sp.toJSONObject();
			ja.put(jo);
		}
		Log.i("LOG","toJSON="+ja.toString());
		Log.i("LOG","toJSON="+ja.toString(1));
		return ja.toString(1);
	}
	
	public void fromJSON(String jsonText) throws JSONException {
		Map<String,SsidParams> newAllParams = new HashMap<String,SsidParams>();

		if (jsonText == null)
			return;
		JSONArray ja = new JSONArray(jsonText);
		for (int i=0; i<ja.length(); i++) {
			JSONObject jo = ja.getJSONObject(i);
			SsidParams pa = new SsidParams();
			pa.fromJSONObject(jo);
			newAllParams.put(pa.getSSID(), pa);
		}
		allParams = newAllParams;
		currentSsidParams = getSsidParams(null);
	}
		
	public SsidParams getSsidParams(String ssid) {
		if (ssid == null)
			ssid = allParams.keySet().iterator().next();
		SsidParams pa = allParams.get(ssid);
		return pa;
	}
	
	public String getSsids() {
		StringBuffer result = new StringBuffer();
		String delimiter = "[";
		for (String key:allParams.keySet()) {
			result.append(delimiter)
					.append(key);
			delimiter = ",";
		}
		result.append("]");
		return result.toString();
	}
	
	public boolean hasSsid(String ssid) {
		return allParams.keySet().contains(ssid);
	}

	public String getInternetPollIntervall() {
		return currentSsidParams.getInternetPollIntervall();
	}

	public String getLoggedInText() {
		return currentSsidParams.getLoggedInText();
	}

	public String getLoggedOutText() {
		return currentSsidParams.getLoggedOutText();
	}

	public String getLogInParams() {
		return currentSsidParams.getLogInParams();
	}

	public String getLogInURL() {
		return currentSsidParams.getLogInURL();
	}

	public String getLogOutURL() {
		return currentSsidParams.getLogOutURL();
	}

	public String getLongWait() {
		return currentSsidParams.getLongWait();
	}

	public String getMediumWait() {
		return currentSsidParams.getMediumWait();
	}

	public long getNumInternetPollIntervall(int defaultValue) {
		return currentSsidParams.getNumInternetPollIntervall(defaultValue);
	}

	public long getNumLongWait(int defaultValue) {
		return currentSsidParams.getNumLongWait(defaultValue);
	}

	public long getNumMediumWait(int defaultValue) {
		return currentSsidParams.getNumMediumWait(defaultValue);
	}

	public long getNumShortWait(int defaultValue) {
		return currentSsidParams.getNumShortWait(defaultValue);
	}

	public long getNumWaitForSsidPollIntervall(int defaultValue) {
		return currentSsidParams.getNumWaitForSsidPollIntervall(defaultValue);
	}

	public String getShortWait() {
		return currentSsidParams.getShortWait();
	}

	public String getSSID() {
		return currentSsidParams.getSSID();
	}

	public String getStatusCheckFailedResponse() {
		return currentSsidParams.getStatusCheckFailedResponse();
	}

	public String getStatusCheckSucceededResponse() {
		return currentSsidParams.getStatusCheckSucceededResponse();
	}

	public String getStatusCheckUrl() {
		return currentSsidParams.getStatusCheckUrl();
	}

	public String getUserAgent() {
		return currentSsidParams.getUserAgent();
	}

	public String getWaitForSsidPollIntervall() {
		return currentSsidParams.getWaitForSsidPollIntervall();
	}

	public void setInternetPollIntervall(String internetPollIntervall) {
		currentSsidParams.setInternetPollIntervall(internetPollIntervall);
	}

	public void setLoggedInText(String loggedInText) {
		currentSsidParams.setLoggedInText(loggedInText);
	}

	public void setLoggedOutText(String loggedOutText) {
		currentSsidParams.setLoggedOutText(loggedOutText);
	}

	public void setLogInParams(String logInParams) {
		currentSsidParams.setLogInParams(logInParams);
	}

	public void setLogInURL(String logInURL) {
		currentSsidParams.setLogInURL(logInURL);
	}

	public void setLogOutURL(String logOutURL) {
		currentSsidParams.setLogOutURL(logOutURL);
	}

	public void setLongWait(String longWait) {
		currentSsidParams.setLongWait(longWait);
	}

	public void setMediumWait(String mediumWait) {
		currentSsidParams.setMediumWait(mediumWait);
	}

	public void setShortWait(String shortWait) {
		currentSsidParams.setShortWait(shortWait);
	}

	public void setSSID(String ssid) {
		currentSsidParams.setSSID(ssid);
	}

	public void setStatusCheckFailedResponse(String statusCheckFailedResponse) {
		currentSsidParams
				.setStatusCheckFailedResponse(statusCheckFailedResponse);
	}

	public void setStatusCheckSucceededResponse(
			String statusCheckSucceededResponse) {
		currentSsidParams
				.setStatusCheckSucceededResponse(statusCheckSucceededResponse);
	}

	public void setStatusCheckUrl(String statusCheckUrl) {
		currentSsidParams.setStatusCheckUrl(statusCheckUrl);
	}

	public void setUserAgent(String userAgent) {
		currentSsidParams.setUserAgent(userAgent);
	}

	public void setWaitForSsidPollIntervall(String waitForSsidPollIntervall) {
		currentSsidParams.setWaitForSsidPollIntervall(waitForSsidPollIntervall);
	}

	public void setCurrentSsid(String ssid) {
		Log.i(TAG, "setCurrentSsid("+ssid+")");
		currentSsidParams = getSsidParams(ssid);
		Log.i(TAG, "SSID="+ssid);
	}
	
}
