/*******************************************************************************
 * Copyright (c) 2009 Ferenc Hechler - ferenc_hechler@users.sourceforge.net
 * 
 * This file is part of the Android Hotspot Login
 *
 * The Android Hotspot Login is free software;
 * you can redistribute it and/or modify it under the terms of the GNU
 * General Public License as published by the Free Software Foundation;
 * either version 2 of the License, or (at your option) any later version.
 * 
 * The Android Hotspot Login is distributed
 * in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with the Android Hotspot Login;
 * if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  
 *******************************************************************************/
package net.sf.andhsli.hotspotlogin;

import org.json.JSONException;
import org.json.JSONObject;


public class SsidParams {

	private static final String TAG = "HSLI.ssidparams";
	private String SSID = "tmobile";
	private String statusCheckUrl = "http://google.de";
	private String statusCheckFailedResponse = "https://hotspot.t-mobile.net";
	private String statusCheckSucceededResponse = "http://www.google.de";
	private String logInURL = "https://hotspot.t-mobile.net/wlan/index.do";
	private String logInParams = "username=$LOGIN|password=$PW|strHinweis=Zahlungsbedingungen|strAGB=AGB";
	private String loggedInText = "Sie sind online.";
	private String loggedOutText = "Login wurde abgelehnt.";
	private String logOutURL = "https://hotspot.t-mobile.net/wlan/goodbye.do";
	private String userAgent = "Android Hotspot Login v0.0.3";
	private String waitForSsidPollIntervall = "60";
	private String internetPollIntervall = "60";
	private String longWait = "60";
	private String mediumWait = "15";
	private String shortWait = "5";

	
	public String toJSON(int indent) throws JSONException {
		JSONObject jo = new JSONObject();
		jo.put("SSID", SSID);
		jo.put("statusCheckUrl", statusCheckUrl);
		jo.put("statusCheckFailedResponse", statusCheckFailedResponse);
		jo.put("statusCheckSucceededResponse", statusCheckSucceededResponse);
		jo.put("logInURL", logInURL);
		jo.put("logInParams", logInParams);
		jo.put("loggedInText", loggedInText);
		jo.put("loggedOutText", loggedOutText);
		jo.put("logOutURL", logOutURL);
		jo.put("userAgent", userAgent);
		jo.put("waitForSsidPollIntervall", waitForSsidPollIntervall);
		jo.put("internetPollIntervall", internetPollIntervall);
		jo.put("shortWait", shortWait);
		jo.put("mediumWait", mediumWait);
		jo.put("longWait", longWait);
		Log.i(TAG,"toString="+jo.toString());
		Log.i(TAG,"toString(1)="+jo.toString(1));
		if (indent == 0)
			return jo.toString();
		return jo.toString(indent);
	}

	public JSONObject toJSONObject() throws JSONException {
		JSONObject jo = new JSONObject();
		jo.put("SSID", SSID);
		jo.put("statusCheckUrl", statusCheckUrl);
		jo.put("statusCheckFailedResponse", statusCheckFailedResponse);
		jo.put("statusCheckSucceededResponse", statusCheckSucceededResponse);
		jo.put("logInURL", logInURL);
		jo.put("logInParams", logInParams);
		jo.put("loggedInText", loggedInText);
		jo.put("loggedOutText", loggedOutText);
		jo.put("logOutURL", logOutURL);
		jo.put("userAgent", userAgent);
		jo.put("waitForSsidPollIntervall", waitForSsidPollIntervall);
		jo.put("internetPollIntervall", internetPollIntervall);
		jo.put("shortWait", shortWait);
		jo.put("mediumWait", mediumWait);
		jo.put("longWait", longWait);
		return jo;
	}
	
	public void fromJSON(String jsonText) throws JSONException {
		if (jsonText == null)
			return;
		JSONObject jo = new JSONObject(jsonText);
		SSID = jo.getString("SSID");
		statusCheckUrl = jo.getString("statusCheckUrl");
		statusCheckFailedResponse = jo.getString("statusCheckFailedResponse");
		statusCheckSucceededResponse = jo.getString("statusCheckSucceededResponse");
		logInURL = jo.getString("logInURL");
		logInParams = jo.getString("logInParams");
		loggedInText = jo.getString("loggedInText");
		loggedOutText = jo.getString("loggedOutText");
		logOutURL = jo.getString("logOutURL");
		userAgent = jo.getString("userAgent");
		waitForSsidPollIntervall = jo.optString("waitForSsidPollIntervall", waitForSsidPollIntervall);
		internetPollIntervall = jo.optString("internetPollIntervall", internetPollIntervall);
		shortWait = jo.optString("shortWait", shortWait);
		mediumWait = jo.optString("mediumWait", mediumWait);
		longWait = jo.optString("longWait", longWait);
	}
	
	public void fromJSONObject(JSONObject jo) throws JSONException {
		SSID = jo.getString("SSID");
		statusCheckUrl = jo.getString("statusCheckUrl");
		statusCheckFailedResponse = jo.getString("statusCheckFailedResponse");
		statusCheckSucceededResponse = jo.getString("statusCheckSucceededResponse");
		logInURL = jo.getString("logInURL");
		logInParams = jo.getString("logInParams");
		loggedInText = jo.getString("loggedInText");
		loggedOutText = jo.getString("loggedOutText");
		logOutURL = jo.getString("logOutURL");
		userAgent = jo.getString("userAgent");
		waitForSsidPollIntervall = jo.optString("waitForSsidPollIntervall", waitForSsidPollIntervall);
		internetPollIntervall = jo.optString("internetPollIntervall", internetPollIntervall);
		shortWait = jo.optString("shortWait", shortWait);
		mediumWait = jo.optString("mediumWait", mediumWait);
		longWait = jo.optString("longWait", longWait);
	}
	
	public String getLongWait() {
		return longWait;
	}
	public void setLongWait(String longWait) {
		this.longWait = longWait;
	}
	public String getMediumWait() {
		return mediumWait;
	}
	public void setMediumWait(String mediumWait) {
		this.mediumWait = mediumWait;
	}
	public String getShortWait() {
		return shortWait;
	}
	public void setShortWait(String shortWait) {
		this.shortWait = shortWait;
	}
	public String getLogInURL() {
		return logInURL;
	}
	public void setLogInURL(String logInURL) {
		this.logInURL = logInURL;
	}
	public String getLogInParams() {
		return logInParams;
	}
	public void setLogInParams(String logInParams) {
		this.logInParams = logInParams;
	}
	public String getLogOutURL() {
		return logOutURL;
	}
	public void setLogOutURL(String logOutURL) {
		this.logOutURL = logOutURL;
	}
	public String getSSID() {
		return SSID;
	}
	public void setSSID(String ssid) {
		SSID = ssid;
	}
	public String getStatusCheckUrl() {
		return statusCheckUrl;
	}
	public void setStatusCheckUrl(String statusCheckUrl) {
		this.statusCheckUrl = statusCheckUrl;
	}
	public String getLoggedInText() {
		return loggedInText;
	}
	public void setLoggedInText(String loggedInText) {
		this.loggedInText = loggedInText;
	}
	public String getLoggedOutText() {
		return loggedOutText;
	}
	public void setLoggedOutText(String loggedOutText) {
		this.loggedOutText = loggedOutText;
	}
	public void setUserAgent(String userAgent) {
		this.userAgent = userAgent;
	}
	public String getUserAgent() {
		return userAgent;
	}
	public String getStatusCheckFailedResponse() {
		return statusCheckFailedResponse;
	}
	public void setStatusCheckFailedResponse(String statusCheckFailedResponse) {
		this.statusCheckFailedResponse = statusCheckFailedResponse;
	}
	public String getStatusCheckSucceededResponse() {
		return statusCheckSucceededResponse;
	}
	public void setStatusCheckSucceededResponse(String statusCheckSucceededResponse) {
		this.statusCheckSucceededResponse = statusCheckSucceededResponse;
	}
	public String getWaitForSsidPollIntervall() {
		return waitForSsidPollIntervall;
	}
	public void setWaitForSsidPollIntervall(String waitForSsidPollIntervall) {
		this.waitForSsidPollIntervall = waitForSsidPollIntervall;
	}
	public String getInternetPollIntervall() {
		return internetPollIntervall;
	}
	public void setInternetPollIntervall(String internetPollIntervall) {
		this.internetPollIntervall = internetPollIntervall;
	}
	
	public long getNumWaitForSsidPollIntervall(int defaultValue) {
		return getNum(waitForSsidPollIntervall, defaultValue);
	}
	public long getNumInternetPollIntervall(int defaultValue) {
		return getNum(internetPollIntervall, defaultValue);
	}
	public long getNumLongWait(int defaultValue) {
		return getNum(longWait, defaultValue);
	}
	public long getNumMediumWait(int defaultValue) {
		return getNum(mediumWait, defaultValue);
	}
	public long getNumShortWait(int defaultValue) {
		return getNum(shortWait, defaultValue);
	}

	private long getNum(String value, int defaultValue) {
		if (value == null) 
			return defaultValue;
		if (value.equals(""))
			return defaultValue;
		try {
			return Long.parseLong(value);
		}
		catch (Exception e) {
			Log.e("HSLI.Params", e.getMessage(), e);
			return defaultValue;
		}
	}
	
}
